==> react-adain-tree-0.0.3.tgz: package/src/AdainTreeNodeRenderDefault.js <==
import React from 'react';
import PropTypes from 'prop-types';
import { getIEVersion } from './utils/browser-utils';
import { isDescendant } from './utils/tree-data-utils';
import {FaFolderOpen, FaFolder} from 'react-icons/lib/fa';

let styles;
// Add extra classes in browsers that don't support flex
if (getIEVersion < 10) {
  styles = {
    row: `row row_NoFlex`,
    rowContents: `rowContents rowContents_NoFlex`,
    rowLabel: `rowLabel rowLabel_NoFlex`,
    rowToolbar: `rowToolbar rowToolbar_NoFlex`,
  };
}

class AdainTreeNodeRenderDefault extends React.Component {
  constructor(props) {
	super(props);
	
	this.handleClick = this.handleClick.bind(this);
  }
  componentDidMount() {
	//this.buttonDivWidth = (this.refs.row.offsetWidth - (this.refs.row.offsetWidth * 0.6)) | 0;
  }
  
  handleClick({ node, path, treeIndex }) {
    this.props.onRowClick({ node, path, treeIndex });
  }
  
  render() {
    const {
      scaffoldBlockPxWidth,
      toggleChildrenVisibility,
      connectDragPreview,
      connectDragSource,
      isDragging,
      canDrop,
      canDrag,
      node,
      draggedNode,
      path,
      treeIndex,
      isSearchMatch,
      isSearchFocus,
      buttons,
      className,
      style,
      didDrop,
	  onRowClick,
	  commonSetting,
      /* eslint-disable no-unused-vars */
      isOver: _isOver, // Not needed, but preserved for other renderers
      parentNode: _parentNode, // Needed for drag-and-drop utils
      endDrag: _endDrag, // Needed for drag-and-drop utils
      startDrag: _startDrag, // Needed for drag-and-drop utils
	  	scaffold: _scaffold,
      /* eslint-enable no-unused-vars */
      ...otherProps
    } = this.props;
    
    let handle;
    if (canDrag) {
      if (typeof node.children === 'function' && node.expanded) {
        // Show a loading symbol on the handle when the children are expanded
        //  and yet still defined by a function (a callback to fetch the children)
        handle = (
          <div className="loadingHandle">
            <div className="loadingCircle">
              <div className="loadingCirclePoint" />
              <div className="oadingCirclePoint" />
              <div className="oadingCirclePoint" />
              <div className="oadingCirclePoint" />
              <div className="oadingCirclePoint" />
              <div className="oadingCirclePoint" />
              <div className="oadingCirclePoint" />
              <div className="oadingCirclePoint" />
              <div className="oadingCirclePoint" />
              <div className="oadingCirclePoint" />
              <div className="oadingCirclePoint" />
              <div className="oadingCirclePoint" />
            </div>
          </div>
        );
      } else {
        // Show the handle used to initiate a drag-and-drop
        handle = connectDragSource(<div className="moveHandle" />, {
          dropEffect: 'copy',
        });
      }
    }

    const isDraggedDescendant = draggedNode && isDescendant(draggedNode, node);
    const isLandingPadActive = !didDrop && isDragging;
    
    const hasCheckBox = (commonSetting && commonSetting.hasCheckBoxAll) || node.hasCheckBox;
    
    return (
      <div ref="row" className="nodeContentWrap"  {...otherProps} onClick={() => this.handleClick({node, path, treeIndex})}>

				{handle}

		<div className="checkWrap">
		  {hasCheckBox &&
		  <div className="checkBoxs">
			<input type="checkbox"/>
		  </div>}
		</div>
		{_scaffold}

        <div className="rowWrapper">
					{toggleChildrenVisibility &&
					node.children &&
					node.children.length > 0 ?
					<div className="folderWrap">
						<button
							type="button"
							aria-label={node.expanded ? 'Collapse' : 'Expand'}
							className={
								node.expanded ? "collapseButton" : "expandButton"
							}
							onClick={() =>
								toggleChildrenVisibility({
									node,
									path,
									treeIndex,
								})
							}
						>
						  {node.expanded ? <FaFolderOpen /> : <FaFolder />}
						</button>

						{node.expanded &&
						!isDragging &&
						<div
							className="lineChildren"
						/>}
					</div> :
						<div className="noChildren"></div>}
					
          {/* Set the row preview to be used during drag and drop */}
          {connectDragPreview(
            <div
              className={
                'row' +
                (isLandingPadActive ? ` rowLandingPad` : '') +
                (isLandingPadActive && !canDrop
                  ? ` rowCancelPad`
                  : '') +
                (isSearchMatch ? ` rowSearchMatch` : '') +
                (isSearchFocus ? ` rowSearchFocus` : '') +
                (className ? ` ${className}` : '')
              }
              style={{
                opacity: isDraggedDescendant ? 0.5 : 1,
                ...style,
              }}
            >

              <div
                className={
                  'rowContents' +
                  (!canDrag ? ` rowContentsDragDisabled` : '')
                }
              >
                <div className="rowLabel">
                  <span
                    className={
                      "rowTitle" +
                      (node.subtitle ? ` rowTitleWithSubtitle` : '')
                    }
                  >
                    {typeof node.title === 'function'
                      ? node.title({
                          node,
                          path,
                          treeIndex,
                        })
                      : node.title}
                  </span>

                  {node.subtitle &&
                    <span className="rowSubtitle">
                      {typeof node.subtitle === 'function'
                        ? node.subtitle({
                            node,
                            path,
                            treeIndex,
                          })
                        : node.subtitle}
                    </span>}
                </div>

                <div 
									className="rowToolbar"
									style={{width: 400}} //node 넓이에서 - 60% 한값을 넣어주는게 좋을거 같음 
								>
                  {buttons.map((btn, index) =>
                    <div
                      key={index} // eslint-disable-line react/no-array-index-key
                      className="toolbarButton"
                    >
                      {btn}
                    </div>
                  )}
                </div>
              </div>
            </div>
          )}
        </div>
      </div>
    );
  }
}

AdainTreeNodeRenderDefault.defaultProps = {
  isSearchMatch: false,
  isSearchFocus: false,
  canDrag: false,
  toggleChildrenVisibility: null,
  buttons: [],
  className: '',
  style: {},
  parentNode: null,
  draggedNode: null,
  canDrop: false,
};

AdainTreeNodeRenderDefault.propTypes = {
  node: PropTypes.shape({}).isRequired,
  path: PropTypes.arrayOf(
    PropTypes.oneOfType([PropTypes.string, PropTypes.number])
  ).isRequired,
  treeIndex: PropTypes.number.isRequired,
  isSearchMatch: PropTypes.bool,
  isSearchFocus: PropTypes.bool,
  canDrag: PropTypes.bool,
  scaffoldBlockPxWidth: PropTypes.number.isRequired,
  toggleChildrenVisibility: PropTypes.func,
  buttons: PropTypes.arrayOf(PropTypes.node),
  className: PropTypes.string,
  style: PropTypes.shape({}),

  onRowClick: PropTypes.func,
  
  // Drag and drop API functions
  // Drag source
  connectDragPreview: PropTypes.func.isRequired,
  connectDragSource: PropTypes.func.isRequired,
  parentNode: PropTypes.shape({}), // Needed for drag-and-drop utils
  startDrag: PropTypes.func.isRequired, // Needed for drag-and-drop utils
  endDrag: PropTypes.func.isRequired, // Needed for drag-and-drop utils
  isDragging: PropTypes.bool.isRequired,
  didDrop: PropTypes.bool.isRequired,
  draggedNode: PropTypes.shape({}),
  // Drop target
  isOver: PropTypes.bool.isRequired,
  canDrop: PropTypes.bool,
  scaffold: PropTypes.arrayOf(PropTypes.node),
};

export default AdainTreeNodeRenderDefault;

==> react-adain-tree-0.0.4.tgz: package/src/AdainTreeNodeRenderDefault.js <==
import React from 'react';
import PropTypes from 'prop-types';
import { getIEVersion } from './utils/browser-utils';
import { isDescendant } from './utils/tree-data-utils';
import {FaFolderOpen, FaFolder} from 'react-icons/lib/fa';

let styles;
// Add extra classes in browsers that don't support flex
if (getIEVersion < 10) {
  styles = {
    row: `row row_NoFlex`,
    rowContents: `rowContents rowContents_NoFlex`,
    rowLabel: `rowLabel rowLabel_NoFlex`,
    rowToolbar: `rowToolbar rowToolbar_NoFlex`,
  };
}

class AdainTreeNodeRenderDefault extends React.Component {
  constructor(props) {
	super(props);
	
	this.handleClick = this.handleClick.bind(this);
  }
  componentDidMount() {
	//this.buttonDivWidth = (this.refs.row.offsetWidth - (this.refs.row.offsetWidth * 0.6)) | 0;
  }
  
  handleClick({ node, path, treeIndex }) {
	this.props.onRowClick({ node, path, treeIndex });
    //this.props.removeAllSelected(treeIndex);
  }
  
  render() {
    const {
      scaffoldBlockPxWidth,
      toggleChildrenVisibility,
      connectDragPreview,
      connectDragSource,
      isDragging,
      canDrop,
      canDrag,
      node,
      draggedNode,
      path,
      treeIndex,
      isSearchMatch,
      isSearchFocus,
      buttons,
      className,
      style,
      didDrop,
	  onRowClick,
	  removeAllSelected,
	  commonSetting,
      /* eslint-disable no-unused-vars */
      isOver: _isOver, // Not needed, but preserved for other renderers
      parentNode: _parentNode, // Needed for drag-and-drop utils
      endDrag: _endDrag, // Needed for drag-and-drop utils
      startDrag: _startDrag, // Needed for drag-and-drop utils
	  	scaffold: _scaffold,
      /* eslint-enable no-unused-vars */
      ...otherProps
    } = this.props;
    
    let handle;
    if (canDrag) {
      if (typeof node.children === 'function' && node.expanded) {
        // Show a loading symbol on the handle when the children are expanded
        //  and yet still defined by a function (a callback to fetch the children)
        handle = (
          <div className="loadingHandle">
            <div className="loadingCircle">
              <div className="loadingCirclePoint" />
              <div className="oadingCirclePoint" />
              <div className="oadingCirclePoint" />
              <div className="oadingCirclePoint" />
              <div className="oadingCirclePoint" />
              <div className="oadingCirclePoint" />
              <div className="oadingCirclePoint" />
              <div className="oadingCirclePoint" />
              <div className="oadingCirclePoint" />
              <div className="oadingCirclePoint" />
              <div className="oadingCirclePoint" />
              <div className="oadingCirclePoint" />
            </div>
          </div>
        );
      } else {
        // Show the handle used to initiate a drag-and-drop
        handle = connectDragSource(<div className="moveHandle" />, {
          dropEffect: 'copy',
        });
      }
    }

    const isDraggedDescendant = draggedNode && isDescendant(draggedNode, node);
    const isLandingPadActive = !didDrop && isDragging;
    
    const hasCheckBox = (commonSetting && commonSetting.hasCheckBoxAll) || node.hasCheckBox;
    
    return (
      <div ref="row" className={'nodeContentWrap' + (node.selected ? ' checked' : '')}  {...otherProps} onClick={() => this.handleClick({node, path, treeIndex})}>

				{handle}

		<div className="checkWrap">
		  {hasCheckBox &&
		  <div className="checkBoxs">
			<input type="checkbox"/>
		  </div>}
		</div>
		{_scaffold}

        <div className="rowWrapper">
					
          {/* Set the row preview to be used during drag and drop */}
          {connectDragPreview(
            <div
              className={
                'row' +
                (isLandingPadActive ? ` rowLandingPad` : '') +
                (isLandingPadActive && !canDrop
                  ? ` rowCancelPad`
                  : '') +
                (isSearchMatch ? ` rowSearchMatch` : '') +
                (isSearchFocus ? ` rowSearchFocus` : '') +
                (className ? ` ${className}` : '')
              }
              style={{
                opacity: isDraggedDescendant ? 0.5 : 1,
                ...style,
              }}
            >

              <div
                className={
                  'rowContents' +
                  (!canDrag ? ` rowContentsDragDisabled` : '')
                }
              >
                <div className="rowLabel">
									{toggleChildrenVisibility &&
									node.children &&
									node.children.length > 0 ?
										<div className="folderWrap">
											<button
												type="button"
												aria-label={node.expanded ? 'Collapse' : 'Expand'}
												className={
													node.expanded ? "collapseButton" : "expandButton"
												}
												onClick={() =>
													toggleChildrenVisibility({
														node,
														path,
														treeIndex,
													})
												}
											>
												{node.expanded ? <FaFolderOpen /> : <FaFolder />}
											</button>

											{node.expanded &&
											!isDragging &&
											<div className="lineChildren" />}
										</div> :
										<div className="noChildren" />}
									
                  <span
                    className={
                      "rowTitle" +
                      (node.subtitle ? ` rowTitleWithSubtitle` : '')
                    }
                  >
                    {typeof node.title === 'function'
                      ? node.title({
                          node,
                          path,
                          treeIndex,
                        })
                      : node.title}
                  </span>

                  {node.subtitle &&
                    <span className="rowSubtitle">
                      {typeof node.subtitle === 'function'
                        ? node.subtitle({
                            node,
                            path,
                            treeIndex,
                          })
                        : node.subtitle}
                    </span>}
                </div>

                <div 
									className="rowToolbar"
									style={{width: 400}} //node 넓이에서 - 60% 한값을 넣어주는게 좋을거 같음 
								>
                  {buttons.map((btn, index) =>
                    <div
                      key={index} // eslint-disable-line react/no-array-index-key
                      className="toolbarButton"
                    >
                      {btn}
                    </div>
                  )}
                </div>
              </div>
            </div>
          )}
        </div>
      </div>
    );
  }
}

AdainTreeNodeRenderDefault.defaultProps = {
  isSearchMatch: false,
  isSearchFocus: false,
  canDrag: false,
  toggleChildrenVisibility: null,
  buttons: [],
  className: '',
  style: {},
  parentNode: null,
  draggedNode: null,
  canDrop: false,
};

AdainTreeNodeRenderDefault.propTypes = {
  node: PropTypes.shape({}).isRequired,
  path: PropTypes.arrayOf(
    PropTypes.oneOfType([PropTypes.string, PropTypes.number])
  ).isRequired,
  treeIndex: PropTypes.number.isRequired,
  isSearchMatch: PropTypes.bool,
  isSearchFocus: PropTypes.bool,
  canDrag: PropTypes.bool,
  scaffoldBlockPxWidth: PropTypes.number.isRequired,
  toggleChildrenVisibility: PropTypes.func,
  buttons: PropTypes.arrayOf(PropTypes.node),
  className: PropTypes.string,
  style: PropTypes.shape({}),

  onRowClick: PropTypes.func,
  
  // Drag and drop API functions
  // Drag source
  connectDragPreview: PropTypes.func.isRequired,
  connectDragSource: PropTypes.func.isRequired,
  parentNode: PropTypes.shape({}), // Needed for drag-and-drop utils
  startDrag: PropTypes.func.isRequired, // Needed for drag-and-drop utils
  endDrag: PropTypes.func.isRequired, // Needed for drag-and-drop utils
  isDragging: PropTypes.bool.isRequired,
  didDrop: PropTypes.bool.isRequired,
  draggedNode: PropTypes.shape({}),
  // Drop target
  isOver: PropTypes.bool.isRequired,
  canDrop: PropTypes.bool,
  scaffold: PropTypes.arrayOf(PropTypes.node),
};

export default AdainTreeNodeRenderDefault;
